# Generated by Django 2.2.6 on 2019-10-17 19:41

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('configuration', '0002_auto_20191017_1646'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='organizationinfosettings',
            options={'verbose_name': 'Organization', 'verbose_name_plural': 'Organization'},
        ),
    ]
