{# IMPORTANT: GOOGLE+ CAN USE OPENGRAPH INSTEAD OF ITS OWN METATAGS.
    For this same reason, this file will not be continued. #}

{% macro website(request, title, description, image) -%}
  <meta itemprop='name' content='{{ title|truncate(70) }}'>
  <meta itemprop='description' content='{{ description }}'>
  <meta itemprop='image' content='{{ image }}'>
{%- endmacro %}
